# BeForData

Data structure for handling behavioural force data

[![GitHub license](https://img.shields.io/github/license/lindemann09/befordata)](https://github.com/lindemann09/befordata/blob/master/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/befordata?style=flat)](https://pypi.org/project/befordata/)

see  https://lindemann09.github.io/befordata/


## Install via pip

```
pip install befordata
```


[BeForData Demo](https://lindemann09.github.io/befordata/demo_befordata.html)


## Julia

A [Julia implementation of BeFordata](https://github.com/lindemann09/BeForData.jl) is under development.

(c) Oliver Lindemann
